pathutil

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Filepath

type Filepath struct {
	IsDir     bool
	Dirpath   string
	Filepath  string
	Extension string
}

Filepath is a structure that holds the main attributes of a file path.

func ParseFilepath

func ParseFilepath(f string) *Filepath

ParseFilepath parses the provided filepath, and extracts several information about it. Returns the dirpath, filepath without extension, and the file extension.

Jump to