Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetFileNameFromURL ¶
GetFileNameFromURL returns a string generated from the provided URL, that can be used as a file name. returns a string that contains the file name and an error if any error occurs.
func ReadUniqueFileLines ¶
ReadUniqueFileLines reads the content of the provided file, and returns a slice of strings that contains the unique lines, or an error if any error occurs.
func SaveFileToDisk ¶
SaveFileToDisk saves the file to disk, and creates the directory if it doesn't exist. The file is saved at the provided path with 0600 permission bits. It returns an error if any error occurs.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.