Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Filepath ¶
Filepath is a structure that holds the main attributes of a file path.
func ParseFilepath ¶
ParseFilepath parses the provided filepath, and extracts several information about it. Returns the dirpath, filepath without extension, and the file extension.
Click to show internal directories.
Click to hide internal directories.